Enum Applicability
#[non_exhaustive]pub(crate) enum Applicability {
MachineApplicable,
HasPlaceholders,
MaybeIncorrect,
Unspecified,
}Expand description
Whether a suggestion can be safely applied.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
MachineApplicable
The suggested replacement can be applied automatically safely
HasPlaceholders
The suggested replacement has placeholders that will need to be manually replaced.
MaybeIncorrect
The suggested replacement may be incorrect in some circumstances. Needs human review.
Unspecified
The suggested replacement will probably not work.