enum DiagnosticsReceived {
NotYet,
AtLeastOne,
AtLeastOneAndClearedWorkspace,
}Variants
NotYet
We started a flycheck, but we haven’t seen any diagnostics yet.
AtLeastOne
We received a non-zero number of diagnostics from rustc or clippy (via cargo or custom check command). This means there were errors or warnings.
AtLeastOneAndClearedWorkspace
We received a non-zero number of diagnostics, and the scope is workspace, so we’ve discarded the previous workspace diagnostics.