DiagnosticSpan

Struct DiagnosticSpan 

#[non_exhaustive]
pub(crate) struct DiagnosticSpan {
Show 13 fields pub file_name: String, pub byte_start: u32, pub byte_end: u32, pub line_start: usize, pub line_end: usize, pub column_start: usize, pub column_end: usize, pub is_primary: bool, pub text: Vec<DiagnosticSpanLine>, pub label: Option<String>, pub suggested_replacement: Option<String>, pub suggestion_applicability: Option<Applicability>, pub expansion: Option<Box<DiagnosticSpanMacroExpansion>>,
}
A section of the source code associated with a Diagnostic

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
file_name: String

The file name or the macro name this diagnostic comes from.

byte_start: u32

The byte offset in the file where this diagnostic starts from.

byte_end: u32

The byte offset in the file where this diagnostic ends.

line_start: usize

1-based. The line in the file.

line_end: usize

1-based. The line in the file.

column_start: usize

1-based, character offset.

column_end: usize

1-based, character offset.

is_primary: bool

Is this a “primary” span – meaning the point, or one of the points, where the error occurred?

There are rare cases where multiple spans are marked as primary, e.g. “immutable borrow occurs here” and “mutable borrow ends here” can be two separate spans both “primary”. Top (parent) messages should always have at least one primary span, unless it has 0 spans. Child messages may have 0 or more primary spans.

text: Vec<DiagnosticSpanLine>

Source text from the start of line_start to the end of line_end.

label: Option<String>

Label that should be placed at this location (if any)

suggested_replacement: Option<String>

If we are suggesting a replacement, this will contain text that should be sliced in atop this span.

suggestion_applicability: Option<Applicability>

If the suggestion is approximate

expansion: Option<Box<DiagnosticSpanMacroExpansion>>

Macro invocations that created the code at this span, if any.