struct Substitutions<'a> {
label: Option<&'a str>,
saved_file: Option<&'a str>,
}Fields
label: Option<&'a str>saved_file: Option<&'a str>Implementations
Sourceimpl<'a> Substitutions<'a>
impl<'a> Substitutions<'a>
Sourcefn substitute<H>(
self,
template: &Runnable,
extra_env: &HashMap<String, Option<String>, H>,
) -> Option<Command>
fn substitute<H>( self, template: &Runnable, extra_env: &HashMap<String, Option<String>, H>, ) -> Option<Command>
If you have a runnable, and it has {label} in it somewhere, treat it as a template that may be unsatisfied if you do not provide a label to substitute into it. Returns None in that situation. Otherwise performs the requested substitutions.
Same for {saved_file}.