pub(crate) struct FlycheckHandle {
sender: Sender<StateChange>,
_thread: JoinHandle,
id: usize,
generation: Arc<AtomicUsize>,
}Expand description
Flycheck wraps the shared state and communication machinery used for
running cargo check (or other compatible command) and providing
diagnostics based on the output.
The spawned thread is shut down when this struct is dropped.
Fields
sender: Sender<StateChange>_thread: JoinHandleid: usizegeneration: Arc<AtomicUsize>Implementations
Sourceimpl FlycheckHandle
impl FlycheckHandle
pub(crate) fn spawn( id: usize, generation: Arc<AtomicUsize>, sender: Sender<FlycheckMessage>, config: FlycheckConfig, config_json: FlycheckConfigJson, sysroot_root: Option<AbsPathBuf>, workspace_root: AbsPathBuf, manifest_path: Option<AbsPathBuf>, ws_target_dir: Option<Utf8PathBuf>, ) -> FlycheckHandle
Sourcepub(crate) fn restart_workspace(&self, saved_file: Option<AbsPathBuf>)
pub(crate) fn restart_workspace(&self, saved_file: Option<AbsPathBuf>)
Schedule a re-start of the cargo check worker to do a workspace wide check.
Sourcepub(crate) fn restart_for_package(
&self,
package: PackageSpecifier,
target: Option<Target>,
workspace_deps: Option<FxHashSet<PackageSpecifier>>,
saved_file: Option<AbsPathBuf>,
)
pub(crate) fn restart_for_package( &self, package: PackageSpecifier, target: Option<Target>, workspace_deps: Option<FxHashSet<PackageSpecifier>>, saved_file: Option<AbsPathBuf>, )
Schedule a re-start of the cargo check worker to do a package wide check.
pub(crate) fn id(&self) -> usize
pub(crate) fn generation(&self) -> usize